@@ -210,6 +210,19 @@ func TestGetPullRequestURL(t *testing.T) {
 				assert.Equal(t, "https://dev.azure.com/myorg/myproject/_git/myrepo/pullrequestcreate?sourceRef=feature%2Fnew&targetRef=dev", url)
 			},
 		},
+		{
+			testName:  "Opens a link to new pull request on Azure DevOps Server (HTTP)",
+			from:      "feature/new",
+			remoteUrl: "https://mycompany.azuredevops.com/collection/myproject/_git/myrepo",
+			configServiceDomains: map[string]string{
+				// valid configuration for a azure devops server URL
+				"mycompany.azuredevops.com": "azuredevops:mycompany.azuredevops.com",
+			},
+			test: func(url string, err error) {
+				assert.NoError(t, err)
+				assert.Equal(t, "https://mycompany.azuredevops.com/collection/myproject/_git/myrepo/pullrequestcreate?sourceRef=feature%2Fnew", url)
+			},
+		},
 		{
 			testName:  "Opens a link to new pull request on Bitbucket Server (SSH)",
 			from:      "feature/new",
