@@ -10,15 +10,18 @@ import (
 
 type JumpToSideWindowController struct {
 	baseController
-	c *ControllerCommon
+	c           *ControllerCommon
+	nextTabFunc func() error
 }
 
 func NewJumpToSideWindowController(
-	common *ControllerCommon,
+	c *ControllerCommon,
+	nextTabFunc func() error,
 ) *JumpToSideWindowController {
 	return &JumpToSideWindowController{
 		baseController: baseController{},
-		c:              common,
+		c:              c,
+		nextTabFunc:    nextTabFunc,
 	}
 }
 
@@ -46,8 +49,14 @@ func (self *JumpToSideWindowController) GetKeybindings(opts types.KeybindingsOpt
 
 func (self *JumpToSideWindowController) goToSideWindow(window string) func() error {
 	return func() error {
+		sideWindowAlreadyActive := self.c.Helpers().Window.CurrentWindow() == window
+		if sideWindowAlreadyActive && self.c.UserConfig().Gui.SwitchTabsWithPanelJumpKeys {
+			return self.nextTabFunc()
+		}
+
 		context := self.c.Helpers().Window.GetContextForWindow(window)
 
-		return self.c.PushContext(context)
+		self.c.Context().Push(context)
+		return nil
 	}
 }
