@@ -7,7 +7,7 @@ import (
 
 var EditFirstCommit = NewIntegrationTest(NewIntegrationTestArgs{
 	Description:  "Edits the first commit, just to show that it's possible",
-	ExtraCmdArgs: "",
+	ExtraCmdArgs: []string{},
 	Skip:         false,
 	SetupConfig:  func(config *config.AppConfig) {},
 	SetupRepo: func(shell *Shell) {
